# pyrandorg

This package introduces the Pyrandorg class, provided with methods to fetch and return true random numbers from random.org. The class also allows for quicker fetch of multiple numbers by using a true random seed along with the default random python package.
